<template>
  <div class="base-image-info">
    <div class="base-image-info__list">
      <div
        v-for="(item, index) in list"
        :key="index"
        class="base-image-info__item"
      >
        <el-ext-upload
          v-model="item.imageUrl"
          list-type="picture-card"
          value-type="string"
          :limit="1"
          @change="onInputChange"
        ></el-ext-upload>
        <el-form label-width="auto" class="base-image-info__main">
          <el-form-item label="标题">
            <el-input v-model="item.title" @change="onInputChange"></el-input>
          </el-form-item>
          <el-form-item label="链接">
            <el-input v-model="item.link" @change="onInputChange"></el-input>
          </el-form-item>
          <el-form-item label="描述">
            <el-input
              v-model="item.desc"
              type="textarea"
              :rows="3"
              @change="onInputChange"
            ></el-input>
          </el-form-item>
        </el-form>
        <div class="base-image-info__delete" @click="deleteItem(index)">
          <i class="el-icon-delete"></i>
        </div>
      </div>
    </div>
    <div class="base-image-info__add">
      <el-button type="primary" icon="el-icon-plus" @click="add"
        >添加</el-button
      >
    </div>
  </div>
</template>

<script>
export default {
  name: 'BaseImageInfo',
  props: {
    value: {
      type: Array,
      default: () => [],
    },
  },
  data() {
    return {
      list: [],
    }
  },
  watch: {
    value: {
      immediate: true,
      handler(value) {
        this.list = value || []
      },
    },
  },
  methods: {
    add() {
      this.list.push({
        imageUrl: '',
        title: '',
        desc: '',
        link: '',
      })
      this.onInputChange()
    },
    deleteItem(index) {
      this.list.splice(index, 1)
      this.onInputChange()
    },
    onInputChange() {
      this.$emit('input', this.list)
      this.$emit('change', this.list)
    },
  },
}
</script>

<style scoped lang="scss">
.base-image-info {
  &__list {
  }
  &__item {
    display: flex;
  }
  &__main {
    margin-left: 15px;
    flex: 1;
    .el-form-item {
      margin-bottom: 5px;
    }
  }
  &__delete {
    cursor: pointer;
    font-size: 20px;
    margin-left: 15px;
    color: $tip-color;
    display: flex;
    align-items: center;
  }
  &__add {
    margin-top: 5px;
  }
}
</style>
